==> jc-1.4.0.tar.gz: soot/grimp/PrecedenceTest.c <==
// public class soot.grimp.PrecedenceTest

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 277f133500573bf0 soot_Value
// @dep_class be495158d4df40c0 soot_ValueBox
// @dep_class 35243f3843c8a553 soot_grimp_Precedence
// @dep_class 62024d1de338216a soot_grimp_PrecedenceTest

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_Value
// @dep_header soot_ValueBox
// @dep_header soot_grimp_Precedence
// @dep_header soot_grimp_PrecedenceTest

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/Value.h"
#include "soot/ValueBox.h"
#include "soot/grimp/Precedence.h"
#include "soot/grimp/PrecedenceTest.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static boolean needsBrackets(soot.ValueBox, soot.Value)
//

static _jc_linenum _jc_soot_grimp_PrecedenceTest$linenum_table$needsBrackets$1ab2203940554dbf[];

static const unsigned char _jc_soot_grimp_PrecedenceTest$param_ptypes$needsBrackets$1ab2203940554dbf[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_soot_grimp_PrecedenceTest$param_types$needsBrackets$1ab2203940554dbf[] = {
	&_jc_soot_ValueBox$type,
	&_jc_soot_Value$type
};

_jc_method _jc_soot_grimp_PrecedenceTest$method_info$needsBrackets$1ab2203940554dbf = {
	.name=			"needsBrackets",
	.signature=		"(Lsoot/ValueBox;Lsoot/Value;)Z",
	.class=			&_jc_soot_grimp_PrecedenceTest$type,
	.param_types=		&_jc_soot_grimp_PrecedenceTest$param_types$needsBrackets$1ab2203940554dbf,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_grimp_PrecedenceTest$param_ptypes$needsBrackets$1ab2203940554dbf,
	.signature_hash=	_JC_JLONG(0x1ab2203940554dbf),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_soot_grimp_PrecedenceTest$method$needsBrackets$1ab2203940554dbf,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_soot_grimp_PrecedenceTest$linenum_table$needsBrackets$1ab2203940554dbf
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_grimp_PrecedenceTest, needsBrackets$1ab2203940554dbf);

jboolean
_jc_soot_grimp_PrecedenceTest$method$needsBrackets$1ab2203940554dbf(_jc_env *const env, _jc_object *param0, _jc_object *param1)
{
	jint i0;
	jint i1;
	struct _jc_object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(71);				// 0
	r2 = _JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x5c68332c5d4a9bf9), _jc_object *);
	_JC_LINE_NUMBER(72);				// 1
	z0 = _JC_INSTANCEOF(env, r2, &_jc_soot_grimp_Precedence$type);
	if (z0 != 0)
		goto label0;
	return 0;

label0:
	_JC_LINE_NUMBER(73);				// 2
	r3 = r2;
	_JC_LINE_NUMBER(74);				// 3
	r4 = _JC_CAST(env, &_jc_soot_grimp_Precedence$type, r1);
	_JC_LINE_NUMBER(75);				// 4
	i0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0x9873747576c8b2e5), jint);
	i1 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x9873747576c8b2e5), jint);
	if (i0 >= i1)
		goto label1;
	z0 = 1;
	goto label2;

label1:
	z0 = 0;

label2:
	return z0;
}

//
// public static boolean needsBracketsRight(soot.ValueBox, soot.Value)
//

static _jc_linenum _jc_soot_grimp_PrecedenceTest$linenum_table$needsBracketsRight$4d5bff97bb4fa2f3[];

static const unsigned char _jc_soot_grimp_PrecedenceTest$param_ptypes$needsBracketsRight$4d5bff97bb4fa2f3[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_soot_grimp_PrecedenceTest$param_types$needsBracketsRight$4d5bff97bb4fa2f3[] = {
	&_jc_soot_ValueBox$type,
	&_jc_soot_Value$type
};

_jc_method _jc_soot_grimp_PrecedenceTest$method_info$needsBracketsRight$4d5bff97bb4fa2f3 = {
	.name=			"needsBracketsRight",
	.signature=		"(Lsoot/ValueBox;Lsoot/Value;)Z",
	.class=			&_jc_soot_grimp_PrecedenceTest$type,
	.param_types=		&_jc_soot_grimp_PrecedenceTest$param_types$needsBracketsRight$4d5bff97bb4fa2f3,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_grimp_PrecedenceTest$param_ptypes$needsBracketsRight$4d5bff97bb4fa2f3,
	.signature_hash=	_JC_JLONG(0x4d5bff97bb4fa2f3),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_soot_grimp_PrecedenceTest$method$needsBracketsRight$4d5bff97bb4fa2f3,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_soot_grimp_PrecedenceTest$linenum_table$needsBracketsRight$4d5bff97bb4fa2f3
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_grimp_PrecedenceTest, needsBracketsRight$4d5bff97bb4fa2f3);

jboolean
_jc_soot_grimp_PrecedenceTest$method$needsBracketsRight$4d5bff97bb4fa2f3(_jc_env *const env, _jc_object *param0, _jc_object *param1)
{
	jint i0;
	jint i1;
	struct _jc_object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(78);				// 0
	r2 = _JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x5c68332c5d4a9bf9), _jc_object *);
	_JC_LINE_NUMBER(79);				// 1
	z0 = _JC_INSTANCEOF(env, r2, &_jc_soot_grimp_Precedence$type);
	if (z0 != 0)
		goto label0;
	return 0;

label0:
	_JC_LINE_NUMBER(80);				// 2
	r3 = r2;
	_JC_LINE_NUMBER(81);				// 3
	r4 = _JC_CAST(env, &_jc_soot_grimp_Precedence$type, r1);
	_JC_LINE_NUMBER(82);				// 4
	i0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0x9873747576c8b2e5), jint);
	i1 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x9873747576c8b2e5), jint);
	if (i0 > i1)
		goto label1;
	z0 = 1;
	goto label2;

label1:
	z0 = 0;

label2:
	return z0;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_grimp_PrecedenceTest$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_grimp_PrecedenceTest$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_grimp_PrecedenceTest$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_grimp_PrecedenceTest$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_grimp_PrecedenceTest$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_grimp_PrecedenceTest$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_grimp_PrecedenceTest$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_grimp_PrecedenceTest, _init$52f4ad9f2989aeee);

void
_jc_soot_grimp_PrecedenceTest$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_grimp_PrecedenceTest$object *this)
{
	struct _jc_soot_grimp_PrecedenceTest$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(68);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_grimp_PrecedenceTest$methods[] = {
	&_jc_soot_grimp_PrecedenceTest$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_grimp_PrecedenceTest$method_info$needsBrackets$1ab2203940554dbf,
	&_jc_soot_grimp_PrecedenceTest$method_info$needsBracketsRight$4d5bff97bb4fa2f3
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_106[] = {
	&_jc_soot_grimp_PrecedenceTest$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_grimp_PrecedenceTest$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[106]=	_jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_106,
	[113]=	_jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_grimp_PrecedenceTest$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/Value",	_JC_JLONG(0x277f133500573bf0) },
	{ "soot/ValueBox",	_JC_JLONG(0xbe495158d4df40c0) },
	{ "soot/grimp/Precedence",	_JC_JLONG(0x35243f3843c8a553) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_grimp_PrecedenceTest$vtype _jc_soot_grimp_PrecedenceTest$type = {
    .type= {
	.name=			"soot/grimp/PrecedenceTest",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x62024d1de338216a),
		.source_file=		"PrecedenceTest.java",
		.instance_size=		sizeof(_jc_soot_grimp_PrecedenceTest$refs) + sizeof(_jc_soot_grimp_PrecedenceTest$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_grimp_PrecedenceTest$methods) / sizeof(*_jc_soot_grimp_PrecedenceTest$methods),
		.methods=		_jc_soot_grimp_PrecedenceTest$methods,
		.instanceof_hash_table=	_jc_soot_grimp_PrecedenceTest$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_grimp_PrecedenceTest$class_depends) / sizeof(*_jc_soot_grimp_PrecedenceTest$class_depends),
		.class_depends=		_jc_soot_grimp_PrecedenceTest$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_grimp_PrecedenceTest= {
	},
    }
};

==> jc-1.4.5.tar.gz: soot/grimp/PrecedenceTest.c <==
// public class soot.grimp.PrecedenceTest

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 277f133500573bf0 soot_Value
// @dep_class be495158d4df40c0 soot_ValueBox
// @dep_class 35243f3843c8a553 soot_grimp_Precedence
// @dep_class 62024d1de338216a soot_grimp_PrecedenceTest

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_Value
// @dep_header soot_ValueBox
// @dep_header soot_grimp_Precedence
// @dep_header soot_grimp_PrecedenceTest

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/Value.h"
#include "soot/ValueBox.h"
#include "soot/grimp/Precedence.h"
#include "soot/grimp/PrecedenceTest.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static boolean needsBrackets(soot.ValueBox, soot.Value)
//

static _jc_linenum _jc_soot_grimp_PrecedenceTest$linenum_table$needsBrackets$1ab2203940554dbf[];

static const unsigned char _jc_soot_grimp_PrecedenceTest$param_ptypes$needsBrackets$1ab2203940554dbf[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_soot_grimp_PrecedenceTest$param_types$needsBrackets$1ab2203940554dbf[] = {
	&_jc_soot_ValueBox$type,
	&_jc_soot_Value$type
};

_jc_method _jc_soot_grimp_PrecedenceTest$method_info$needsBrackets$1ab2203940554dbf = {
	.name=			"needsBrackets",
	.signature=		"(Lsoot/ValueBox;Lsoot/Value;)Z",
	.class=			&_jc_soot_grimp_PrecedenceTest$type,
	.param_types=		&_jc_soot_grimp_PrecedenceTest$param_types$needsBrackets$1ab2203940554dbf,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_grimp_PrecedenceTest$param_ptypes$needsBrackets$1ab2203940554dbf,
	.signature_hash=	_JC_JLONG(0x1ab2203940554dbf),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_soot_grimp_PrecedenceTest$method$needsBrackets$1ab2203940554dbf,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_soot_grimp_PrecedenceTest$linenum_table$needsBrackets$1ab2203940554dbf
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_grimp_PrecedenceTest, needsBrackets$1ab2203940554dbf);

jboolean _JC_JCNI_ATTR
_jc_soot_grimp_PrecedenceTest$method$needsBrackets$1ab2203940554dbf(_jc_env *const env, _jc_object *param0, _jc_object *param1)
{
	jint i0;
	jint i1;
	struct _jc_object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(71);				// 0
	r2 = _JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x5c68332c5d4a9bf9), _jc_object *, (_jc_env *, struct _jc_object *));
	_JC_LINE_NUMBER(72);				// 1
	z0 = _JC_INSTANCEOF(env, r2, &_jc_soot_grimp_Precedence$type);
	if (z0 != 0)
		goto label0;
	return 0;

label0:
	_JC_LINE_NUMBER(73);				// 2
	r3 = r2;
	_JC_LINE_NUMBER(74);				// 3
	r4 = _JC_CAST(env, &_jc_soot_grimp_Precedence$type, r1);
	_JC_LINE_NUMBER(75);				// 4
	i0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0x9873747576c8b2e5), jint, (_jc_env *, struct _jc_object *));
	i1 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x9873747576c8b2e5), jint, (_jc_env *, struct _jc_object *));
	if (i0 >= i1)
		goto label1;
	z0 = 1;
	goto label2;

label1:
	z0 = 0;

label2:
	return z0;
}

//
// public static boolean needsBracketsRight(soot.ValueBox, soot.Value)
//

static _jc_linenum _jc_soot_grimp_PrecedenceTest$linenum_table$needsBracketsRight$4d5bff97bb4fa2f3[];

static const unsigned char _jc_soot_grimp_PrecedenceTest$param_ptypes$needsBracketsRight$4d5bff97bb4fa2f3[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_soot_grimp_PrecedenceTest$param_types$needsBracketsRight$4d5bff97bb4fa2f3[] = {
	&_jc_soot_ValueBox$type,
	&_jc_soot_Value$type
};

_jc_method _jc_soot_grimp_PrecedenceTest$method_info$needsBracketsRight$4d5bff97bb4fa2f3 = {
	.name=			"needsBracketsRight",
	.signature=		"(Lsoot/ValueBox;Lsoot/Value;)Z",
	.class=			&_jc_soot_grimp_PrecedenceTest$type,
	.param_types=		&_jc_soot_grimp_PrecedenceTest$param_types$needsBracketsRight$4d5bff97bb4fa2f3,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_soot_grimp_PrecedenceTest$param_ptypes$needsBracketsRight$4d5bff97bb4fa2f3,
	.signature_hash=	_JC_JLONG(0x4d5bff97bb4fa2f3),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_soot_grimp_PrecedenceTest$method$needsBracketsRight$4d5bff97bb4fa2f3,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_soot_grimp_PrecedenceTest$linenum_table$needsBracketsRight$4d5bff97bb4fa2f3
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_grimp_PrecedenceTest, needsBracketsRight$4d5bff97bb4fa2f3);

jboolean _JC_JCNI_ATTR
_jc_soot_grimp_PrecedenceTest$method$needsBracketsRight$4d5bff97bb4fa2f3(_jc_env *const env, _jc_object *param0, _jc_object *param1)
{
	jint i0;
	jint i1;
	struct _jc_object *r0;
	struct _jc_object *r1;
	struct _jc_object *r2;
	struct _jc_object *r3;
	struct _jc_object *r4;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(78);				// 0
	r2 = _JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x5c68332c5d4a9bf9), _jc_object *, (_jc_env *, struct _jc_object *));
	_JC_LINE_NUMBER(79);				// 1
	z0 = _JC_INSTANCEOF(env, r2, &_jc_soot_grimp_Precedence$type);
	if (z0 != 0)
		goto label0;
	return 0;

label0:
	_JC_LINE_NUMBER(80);				// 2
	r3 = r2;
	_JC_LINE_NUMBER(81);				// 3
	r4 = _JC_CAST(env, &_jc_soot_grimp_Precedence$type, r1);
	_JC_LINE_NUMBER(82);				// 4
	i0 = _JC_INVOKE_INTERFACE(env, r3, _JC_JLONG(0x9873747576c8b2e5), jint, (_jc_env *, struct _jc_object *));
	i1 = _JC_INVOKE_INTERFACE(env, r4, _JC_JLONG(0x9873747576c8b2e5), jint, (_jc_env *, struct _jc_object *));
	if (i0 > i1)
		goto label1;
	z0 = 1;
	goto label2;

label1:
	z0 = 0;

label2:
	return z0;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_grimp_PrecedenceTest$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_grimp_PrecedenceTest$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_grimp_PrecedenceTest$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_grimp_PrecedenceTest$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_grimp_PrecedenceTest$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_grimp_PrecedenceTest$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_grimp_PrecedenceTest$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_grimp_PrecedenceTest, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_grimp_PrecedenceTest$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_grimp_PrecedenceTest$object *this)
{
	struct _jc_soot_grimp_PrecedenceTest$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(68);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_grimp_PrecedenceTest$methods[] = {
	&_jc_soot_grimp_PrecedenceTest$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_grimp_PrecedenceTest$method_info$needsBrackets$1ab2203940554dbf,
	&_jc_soot_grimp_PrecedenceTest$method_info$needsBracketsRight$4d5bff97bb4fa2f3
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_106[] = {
	&_jc_soot_grimp_PrecedenceTest$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_grimp_PrecedenceTest$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_101,
	[106]=	_jc_soot_grimp_PrecedenceTest$instanceof_hash_bucket_106
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_grimp_PrecedenceTest$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/Value",	_JC_JLONG(0x277f133500573bf0) },
	{ "soot/ValueBox",	_JC_JLONG(0xbe495158d4df40c0) },
	{ "soot/grimp/Precedence",	_JC_JLONG(0x35243f3843c8a553) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_grimp_PrecedenceTest$vtype _jc_soot_grimp_PrecedenceTest$type = {
    .type= {
	.name=			"soot/grimp/PrecedenceTest",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x62024d1de338216a),
		.source_file=		"PrecedenceTest.java",
		.instance_size=		sizeof(_jc_soot_grimp_PrecedenceTest$refs) + sizeof(_jc_soot_grimp_PrecedenceTest$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_grimp_PrecedenceTest$methods) / sizeof(*_jc_soot_grimp_PrecedenceTest$methods),
		.methods=		_jc_soot_grimp_PrecedenceTest$methods,
		.instanceof_hash_table=	_jc_soot_grimp_PrecedenceTest$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_grimp_PrecedenceTest$class_depends) / sizeof(*_jc_soot_grimp_PrecedenceTest$class_depends),
		.class_depends=		_jc_soot_grimp_PrecedenceTest$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_grimp_PrecedenceTest= {
	},
    }
};
